@@ -38,6 +38,26 @@ namespace LMU_Reader {
 	 * Loads map as XML.
 	 */
 	std::unique_ptr<RPG::Map> LoadXml(const std::string& filename);
+
+	/**
+	 * Loads map.
+	 */
+	std::unique_ptr<RPG::Map> Load(std::istream& filestream, const std::string& encoding);
+
+	/**
+	 * Saves map.
+	 */
+	bool Save(std::ostream& filestream, const RPG::Map& map, const std::string& encoding);
+
+	/**
+	 * Saves map as XML.
+	 */
+	bool SaveXml(std::ostream& filestream, const RPG::Map& map);
+
+	/**
+	 * Loads map as XML.
+	 */
+	std::unique_ptr<RPG::Map> LoadXml(std::istream& filestream);
 }
 
 #endif
